==> knapster-0.10.tar.gz: knapster-0.10/knapster/napsterupload.h <==
/***************************************************************************
                          napsterupload.h  -  description
                             -------------------
    begin                : Fri Feb 4 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAPSTERUPLOAD_H
#define NAPSTERUPLOAD_H

#include <napstertransfer.h>

/**
  *@author John Donoghue
  */

class NapsterUpload : public NapsterTransfer
{
  char _buffer[1024];

  int _sock;
//  int _file;

  pthread_t _id;

public: 
	NapsterUpload(long ip,int port,const char *filename,const char *user,
         int speed,const char *dest);
	virtual ~NapsterUpload();

  // for uploads must give listener and start_sz
  bool start(int listen,long start_sz);
private:
  static void *thread_task(NapsterUpload *dl);

};

#endif

==> knapster-0.12.tar.gz: knapster-0.12/knapster/napsterupload.h <==
/***************************************************************************
                          napsterupload.h  -  description
                             -------------------
    begin                : Fri Feb 4 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAPSTERUPLOAD_H
#define NAPSTERUPLOAD_H

#include <napstertransfer.h>

/**
  *@author John Donoghue
  */

class NapsterUpload : public NapsterTransfer
{
  char _buffer[1024+2];

  int _sock;
//  int _file;

  pthread_t _id;

public: 
	NapsterUpload(long ip,int port,const char *filename,const char *user,
         int speed,const char *dest);
	virtual ~NapsterUpload();

  // for uploads must give listener and start_sz
  // unless its a new upload
  bool start(int listen=-1,long start_sz=0);
private:
  static void *thread_task(NapsterUpload *dl);

  bool upload();

  bool upload_new();

};

#endif
